==> dojo-1.9.11.jar: META-INF/resources/webjars/dojo/1.9.11/cldr/nls/roc.js <==
define({ root:

//begin v1.x content
{
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Day of the Week",
	"months@localeAlias480": {
		"bundle": "gregorian",
		"target": "months"
	},
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"dateFormatItem-MMMEd": "MMM d, E",
	"eraNarrow": [
		"Before R.O.C.",
		"R.O.C."
	],
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"dateFormat-long": "G y MMMM d",
	"months-format-wide": [
		"Month1",
		"Month2",
		"Month3",
		"Month4",
		"Month5",
		"Month6",
		"Month7",
		"Month8",
		"Month9",
		"Month10",
		"Month11",
		"Month12"
	],
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "G y MMMM d, EEEE",
	"eraNames@localeAlias510": {
		"bundle": "roc",
		"target": "eraAbbr"
	},
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"dateFormat@localeAlias512": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"quarters-format-abbr@localeAlias498": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"quarters-format-narrow@localeAlias499": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"dayPeriods-format-narrow@localeAlias505": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dayPeriods-format-narrow@localeAlias506": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-wide"
	},
	"dateFormatItem-Md": "MM-dd",
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-narrow@localeAlias508": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"dayPeriods-format-narrow@localeAlias509": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-wide"
	},
	"field-era": "Era",
	"months-standAlone-wide@localeAlias485": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"months-standAlone-wide": [
		"Month1",
		"Month2",
		"Month3",
		"Month4",
		"Month5",
		"Month6",
		"Month7",
		"Month8",
		"Month9",
		"Month10",
		"Month11",
		"Month12"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "Year",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-hour": "Hour",
	"months-format-abbr": [
		"Month1",
		"Month2",
		"Month3",
		"Month4",
		"Month5",
		"Month6",
		"Month7",
		"Month8",
		"Month9",
		"Month10",
		"Month11",
		"Month12"
	],
	"timeFormat@localeAlias513": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-day-relative+0": "Today",
	"field-day-relative+1": "Tomorrow",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"months-standAlone-abbr": [
		"Month1",
		"Month2",
		"Month3",
		"Month4",
		"Month5",
		"Month6",
		"Month7",
		"Month8",
		"Month9",
		"Month10",
		"Month11",
		"Month12"
	],
	"dateFormatItem-H": "HH",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-Gy": "G y",
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dayPeriods@localeAlias503": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"dateFormatItem-yyyyMMM": "G y MMM",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"months-standAlone-abbr@localeAlias483": {
		"bundle": "gregorian",
		"target": "months-format-abbr"
	},
	"months-standAlone-abbr@localeAlias484": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"months-format-abbr@localeAlias481": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"timeFormat-medium": "HH:mm:ss",
	"quarters-standAlone-wide@localeAlias502": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-Hm": "HH:mm",
	"eraAbbr": [
		"Before R.O.C.",
		"R.O.C."
	],
	"field-minute": "Minute",
	"field-dayperiod": "Dayperiod",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters@localeAlias497": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "Yesterday",
	"dayPeriods-format-narrow-am": "AM",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-h": "h a",
	"dateFormatItem-MMMd": "MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"dateTimeFormat-full": "{1} {0}",
	"field-day": "Day",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-format-narrow@localeAlias482": {
		"bundle": "gregorian",
		"target": "months-standAlone-narrow"
	},
	"field-zone": "Zone",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dateFormatItem-y": "G y",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"dateFormatItem-hm": "h:mm a",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dayPeriods-format-abbr-pm": "PM",
	"days-format-short@localeAlias489": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"eraNames": [
		"Before R.O.C.",
		"R.O.C."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"quarters-standAlone-abbr@localeAlias500": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias501": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"dateTime@localeAlias514": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dayPeriods-format-abbr@localeAlias504": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-wide"
	},
	"dateFormatItem-MMM": "LLL",
	"field-month": "Month",
	"eraNarrow@localeAlias511": {
		"bundle": "roc",
		"target": "eraAbbr"
	},
	"dayPeriods-format-abbr@localeAlias507": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-wide"
	},
	"days-standAlone-wide@localeAlias496": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"dayPeriods-format-wide-am": "AM",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"days-format-short@localeAlias490": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormat-short": "GGGGG y-MM-dd",
	"field-second": "Second",
	"days-standAlone-abbr@localeAlias491": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-abbr@localeAlias492": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"days-standAlone-short@localeAlias493": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"days-standAlone-short@localeAlias494": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-short@localeAlias495": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"days-format-abbr@localeAlias487": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-Ed": "d, E",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Week",
	"dateFormat-medium": "G y MMM d",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"days-format-narrow@localeAlias488": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"dateFormatItem-hms": "h:mm:ss a",
	"days@localeAlias486": {
		"bundle": "gregorian",
		"target": "days"
	},
	"dateFormatItem-GyMMM": "G y MMM",
	"dateFormatItem-yyyy": "G y"
}
//end v1.x content
,
	"ar": true,
	"ca": true,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"en": true,
	"es": true,
	"fi": true,
	"fr": true,
	"hr": true,
	"hu": true,
	"it": true,
	"ja": true,
	"ko": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"pt": true,
	"pt-pt": true,
	"ru": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});

==> dojo-1.11.2.jar: META-INF/resources/webjars/dojo/1.11.2/cldr/nls/roc.js <==
define({ root:

//begin v1.x content
{
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "Year",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "HH:mm",
	"field-minute": "Minute",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"dayPeriods@localeAlias555": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "MMM d",
	"dayPeriods-format-abbr-am": "AM",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"timeFormat-medium": "HH:mm:ss",
	"field-second-relative+0": "now",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"eraNames": [
		"Before R.O.C.",
		"R.O.C."
	],
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-day": "Day",
	"field-year-relative+-1": "last year",
	"dayPeriods-format-wide-am": "AM",
	"dateTime@localeAlias562": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"days-format-narrow@localeAlias540": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1} {0}",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"field-second": "Second",
	"days@localeAlias538": {
		"bundle": "gregorian",
		"target": "days"
	},
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "G y MMMM d",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"eraNames@localeAlias558": {
		"bundle": "roc",
		"target": "eraAbbr"
	},
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "G y MMM",
	"field-month": "Month",
	"dateFormatItem-MMM": "LLL",
	"field-dayperiod": "Dayperiod",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "G y MMM d",
	"eraAbbr": [
		"Before R.O.C.",
		"R.O.C."
	],
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"days-standAlone-wide@localeAlias548": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+-1": "last Saturday",
	"quarters@localeAlias549": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "MM-dd",
	"days-standAlone-abbr@localeAlias543": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-hour": "Hour",
	"days-standAlone-abbr@localeAlias544": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"months-format-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dateFormat-full": "G y MMMM d, EEEE",
	"field-month-relative+-1": "last month",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"quarters-format-narrow@localeAlias551": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"dayPeriods-format-narrow-noon": "n",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"days-format-abbr@localeAlias539": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-week-relative+-1": "last week",
	"dateFormatItem-Ehm": "E h:mm a",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"timeFormat-long": "HH:mm:ss z",
	"months@localeAlias532": {
		"bundle": "gregorian",
		"target": "months"
	},
	"dateFormat-short": "GGGGG y-MM-dd",
	"months-format-abbr@localeAlias533": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "G y",
	"months-format-narrow@localeAlias534": {
		"bundle": "gregorian",
		"target": "months-standAlone-narrow"
	},
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-sun-relative+-1": "last Sunday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormat@localeAlias560": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"dateFormatItem-d": "d",
	"field-weekday": "Day of the Week",
	"field-sat-relative+0": "this Saturday",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "next Saturday",
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"quarters-standAlone-wide@localeAlias554": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-MEd": "MM-dd, E",
	"dateFormatItem-y": "G y",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"dayPeriods-format-abbr-noon": "noon",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-thu-relative+-1": "last Thursday",
	"field-week": "Week",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dateFormatItem-Ed": "d, E",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-standAlone-abbr@localeAlias552": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias553": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"eraNarrow": [
		"Before R.O.C.",
		"R.O.C."
	],
	"quarters-format-abbr@localeAlias550": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"days-standAlone-short@localeAlias545": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"months-standAlone-wide@localeAlias537": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"days-standAlone-short@localeAlias546": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dayPeriods-format-wide-noon": "noon",
	"days-standAlone-short@localeAlias547": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dayPeriods-format-abbr@localeAlias556": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-wide"
	},
	"dayPeriods-format-abbr@localeAlias557": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-wide"
	},
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"dateFormatItem-EHm": "E HH:mm",
	"months-standAlone-abbr@localeAlias535": {
		"bundle": "gregorian",
		"target": "months-format-abbr"
	},
	"field-zone": "Zone",
	"months-standAlone-abbr@localeAlias536": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"days-format-short@localeAlias541": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dateFormatItem-MMMEd": "MMM d, E",
	"days-format-short@localeAlias542": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-EHms": "E HH:mm:ss",
	"eraNarrow@localeAlias559": {
		"bundle": "roc",
		"target": "eraAbbr"
	},
	"field-day-relative+-1": "yesterday",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-Gy": "G y",
	"field-era": "Era",
	"timeFormat@localeAlias561": {
		"bundle": "gregorian",
		"target": "timeFormat"
	}
}
//end v1.x content
,
	"ar": true,
	"ca": true,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"en": true,
	"es": true,
	"fi": true,
	"fr": true,
	"hr": true,
	"hu": true,
	"it": true,
	"ja": true,
	"ko": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"pt": true,
	"pt-pt": true,
	"ru": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});
